@@ -14,7 +14,9 @@ import (
 
 	"go.k6.io/k6/internal/event"
 	"go.k6.io/k6/internal/ui/console"
+	"go.k6.io/k6/internal/usage"
 	"go.k6.io/k6/lib/fsext"
+	"go.k6.io/k6/secretsource"
 )
 
 const defaultConfigFileName = "config.json"
@@ -35,12 +37,13 @@ const defaultConfigFileName = "config.json"
 type GlobalState struct {
 	Ctx context.Context
 
-	FS         fsext.Fs
-	Getwd      func() (string, error)
-	BinaryName string
-	CmdArgs    []string
-	Env        map[string]string
-	Events     *event.System
+	FS              fsext.Fs
+	Getwd           func() (string, error)
+	UserOSConfigDir string
+	BinaryName      string
+	CmdArgs         []string
+	Env             map[string]string
+	Events          *event.System
 
 	DefaultFlags, Flags GlobalFlags
 
@@ -54,6 +57,9 @@ type GlobalState struct {
 
 	Logger         *logrus.Logger //nolint:forbidigo //TODO:change to FieldLogger
 	FallbackLogger logrus.FieldLogger
+
+	SecretsManager *secretsource.Manager
+	Usage          *usage.Usage
 }
 
 // NewGlobalState returns a new GlobalState with the given ctx.
@@ -106,29 +112,31 @@ func NewGlobalState(ctx context.Context) *GlobalState {
 	defaultFlags := GetDefaultFlags(confDir)
 
 	return &GlobalState{
-		Ctx:          ctx,
-		FS:           fsext.NewOsFs(),
-		Getwd:        os.Getwd,
-		BinaryName:   filepath.Base(binary),
-		CmdArgs:      os.Args,
-		Env:          env,
-		Events:       event.NewEventSystem(100, logger),
-		DefaultFlags: defaultFlags,
-		Flags:        getFlags(defaultFlags, env),
-		OutMutex:     outMutex,
-		Stdout:       stdout,
-		Stderr:       stderr,
-		Stdin:        os.Stdin,
-		OSExit:       os.Exit,
-		SignalNotify: signal.Notify,
-		SignalStop:   signal.Stop,
-		Logger:       logger,
+		Ctx:             ctx,
+		FS:              fsext.NewOsFs(),
+		Getwd:           os.Getwd,
+		UserOSConfigDir: confDir,
+		BinaryName:      filepath.Base(binary),
+		CmdArgs:         os.Args,
+		Env:             env,
+		Events:          event.NewEventSystem(100, logger),
+		DefaultFlags:    defaultFlags,
+		Flags:           getFlags(defaultFlags, env),
+		OutMutex:        outMutex,
+		Stdout:          stdout,
+		Stderr:          stderr,
+		Stdin:           os.Stdin,
+		OSExit:          os.Exit,
+		SignalNotify:    signal.Notify,
+		SignalStop:      signal.Stop,
+		Logger:          logger,
 		FallbackLogger: &logrus.Logger{ // we may modify the other one
 			Out:       stderr,
 			Formatter: new(logrus.TextFormatter), // no fancy formatting here
 			Hooks:     make(logrus.LevelHooks),
 			Level:     logrus.InfoLevel,
 		},
+		Usage: usage.New(),
 	}
 }
 
@@ -140,6 +148,7 @@ type GlobalFlags struct {
 	Address          string
 	ProfilingEnabled bool
 	LogOutput        string
+	SecretSource     []string
 	LogFormat        string
 	Verbose          bool
 }
@@ -149,7 +158,7 @@ func GetDefaultFlags(homeDir string) GlobalFlags {
 	return GlobalFlags{
 		Address:          "localhost:6565",
 		ProfilingEnabled: false,
-		ConfigFilePath:   filepath.Join(homeDir, "loadimpact", "k6", defaultConfigFileName),
+		ConfigFilePath:   filepath.Join(homeDir, "k6", defaultConfigFileName),
 		LogOutput:        "stderr",
 	}
 }
