@@ -17,6 +17,7 @@ import (
 	expws "go.k6.io/k6/internal/js/modules/k6/experimental/websockets"
 	"go.k6.io/k6/internal/js/modules/k6/grpc"
 	"go.k6.io/k6/internal/js/modules/k6/metrics"
+	"go.k6.io/k6/internal/js/modules/k6/secrets"
 	"go.k6.io/k6/internal/js/modules/k6/timers"
 	"go.k6.io/k6/internal/js/modules/k6/webcrypto"
 	"go.k6.io/k6/internal/js/modules/k6/ws"
@@ -31,17 +32,19 @@ import (
 
 func getInternalJSModules() map[string]interface{} {
 	return map[string]interface{}{
-		"k6":                         k6.New(),
-		"k6/crypto":                  crypto.New(),
-		"k6/crypto/x509":             x509.New(),
-		"k6/data":                    data.New(),
-		"k6/encoding":                encoding.New(),
-		"k6/timers":                  timers.New(),
-		"k6/execution":               execution.New(),
-		"k6/experimental/csv":        csv.New(),
-		"k6/experimental/redis":      redis.New(),
-		"k6/experimental/streams":    streams.New(),
-		"k6/experimental/webcrypto":  webcrypto.New(),
+		"k6":                      k6.New(),
+		"k6/crypto":               crypto.New(),
+		"k6/crypto/x509":          x509.New(),
+		"k6/data":                 data.New(),
+		"k6/encoding":             encoding.New(),
+		"k6/timers":               timers.New(),
+		"k6/execution":            execution.New(),
+		"k6/experimental/csv":     csv.New(),
+		"k6/experimental/redis":   redis.New(),
+		"k6/experimental/streams": streams.New(),
+		"k6/experimental/webcrypto": newWarnExperimentalModule(webcrypto.New(),
+			"k6/experimental/webcrypto is now part of the k6 core, and globally available. You could just remove import."+
+				" The k6/experimental/webcrypto will be removed in k6 v1.1.0"),
 		"k6/experimental/websockets": expws.New(),
 		"k6/experimental/timers": newRemovedModule(
 			"k6/experimental/timers has been graduated, please use k6/timers instead."),
@@ -60,6 +63,7 @@ func getInternalJSModules() map[string]interface{} {
 		"k6/html":            html.New(),
 		"k6/http":            http.New(),
 		"k6/metrics":         metrics.New(),
+		"k6/secrets":         secrets.New(),
 		"k6/ws":              ws.New(),
 		"k6/experimental/grpc": newRemovedModule(
 			"k6/experimental/grpc has been graduated, please use k6/net/grpc instead." +
@@ -80,14 +84,12 @@ func getJSModules() map[string]interface{} {
 	return result
 }
 
-//nolint:unused // this is likely going to be used again even if isn't currently used
 type warnExperimentalModule struct {
 	once *sync.Once
 	msg  string
 	base modules.Module
 }
 
-//nolint:unused // this is likely going to be used again even if isn't currently used
 func newWarnExperimentalModule(base modules.Module, msg string) modules.Module {
 	return &warnExperimentalModule{
 		msg:  msg,
@@ -96,7 +98,6 @@ func newWarnExperimentalModule(base modules.Module, msg string) modules.Module {
 	}
 }
 
-//nolint:unused // this is likely going to be used again even if isn't currently used
 func (w *warnExperimentalModule) NewModuleInstance(vu modules.VU) modules.Instance {
 	w.once.Do(func() { vu.InitEnv().Logger.Warn(w.msg) })
 	return w.base.NewModuleInstance(vu)
