@@ -63,16 +63,16 @@ func (mi *ModuleInstance) expectedStatuses(args ...sobek.Value) *expectedStatuse
 		if isInt(arg) {
 			result.exact = append(result.exact, int(o.ToInteger()))
 		} else {
-			min := o.Get("min")
-			max := o.Get("max")
-			if min == nil || max == nil {
+			minValue := o.Get("min")
+			maxValue := o.Get("max")
+			if minValue == nil || maxValue == nil {
 				common.Throw(rt, fmt.Errorf(errMsg, i+1))
 			}
-			if !(isInt(min) && isInt(max)) {
+			if !(isInt(minValue) && isInt(maxValue)) {
 				common.Throw(rt, fmt.Errorf("both min and max need to be integers for argument number %d", i+1))
 			}
 
-			result.minmax = append(result.minmax, [2]int{int(min.ToInteger()), int(max.ToInteger())})
+			result.minmax = append(result.minmax, [2]int{int(minValue.ToInteger()), int(maxValue.ToInteger())})
 		}
 	}
 	return &result
