@@ -9,7 +9,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"go.k6.io/k6/lib/testutils/mockresolver"
+	"go.k6.io/k6/internal/lib/testutils/mockresolver"
 	"go.k6.io/k6/lib/types"
 )
 
